@@ -90,14 +90,6 @@ EntityTreeModelPrivate::EntityTreeModelPrivate(EntityTreeModel *parent)
     // using collection as a parameter of a queued call in runItemFetchJob()
     qRegisterMetaType<Collection>();
 
-    org::freedesktop::Akonadi::AgentManager *manager =
-        new org::freedesktop::Akonadi::AgentManager(ServerManager::serviceName(Akonadi::ServerManager::Control),
-                                                    QLatin1String("/AgentManager"),
-                                                    DBusConnectionPool::threadConnection(), q_ptr);
-
-    QObject::connect(manager, SIGNAL(agentInstanceAdvancedStatusChanged(QString,QVariantMap)),
-                     q_ptr, SLOT(agentInstanceAdvancedStatusChanged(QString,QVariantMap)));
-
     Akonadi::AgentManager *agentManager = Akonadi::AgentManager::self();
     QObject::connect(agentManager, SIGNAL(instanceRemoved(Akonadi::AgentInstance)),
                      q_ptr, SLOT(agentInstanceRemoved(Akonadi::AgentInstance)));
@@ -221,31 +213,6 @@ void EntityTreeModelPrivate::agentInstanceRemoved(const Akonadi::AgentInstance &
     }
 }
 
-void EntityTreeModelPrivate::agentInstanceAdvancedStatusChanged(const QString &, const QVariantMap &status)
-{
-    const QString key = status.value(QLatin1String("key")).toString();
-    if (key != QLatin1String("collectionSyncProgress")) {
-        return;
-    }
-
-    const Collection::Id collectionId = status.value(QLatin1String("collectionId")).toLongLong();
-    const uint percent = status.value(QLatin1String("percent")).toUInt();
-    if (m_collectionSyncProgress.value(collectionId) == percent) {
-        return;
-    }
-    m_collectionSyncProgress.insert(collectionId, percent);
-
-    const QModelIndex collectionIndex = indexForCollection(Collection(collectionId));
-    if (!collectionIndex.isValid()) {
-        return;
-    }
-
-    Q_Q(EntityTreeModel);
-    // This is really slow (80 levels of method calls in proxy models...), and called
-    // very often during an imap sync...
-    q->dataChanged(collectionIndex, collectionIndex);
-}
-
 void EntityTreeModelPrivate::fetchItems(const Collection &parent)
 {
     Q_Q(const EntityTreeModel);
@@ -1911,9 +1878,9 @@ void EntityTreeModelPrivate::fillModel()
     const QList<Collection> collections = m_monitor->collectionsMonitored();
 
     if (collections.isEmpty() &&
-        m_monitor->mimeTypesMonitored().isEmpty() &&
-        m_monitor->resourcesMonitored().isEmpty() &&
-        !m_monitor->itemsMonitoredEx().isEmpty()) {
+        m_monitor->numMimeTypesMonitored() == 0 &&
+        m_monitor->numResourcesMonitored() == 0 &&
+        m_monitor->numItemsMonitored() != 0) {
         m_rootCollection = Collection(-1);
         m_collectionTreeFetched = true;
         emit q_ptr->collectionTreeFetched(collections);     // there are no collections to fetch
