@@ -22,7 +22,6 @@
 
 #include <QObject>
 
-class KJob;
 
 /**
   This class uses the ClearErrorAction to mark all failed messages in the
@@ -35,7 +34,7 @@ class Runner : public QObject
   public:
     Runner();
 
-  private slots:
+  private Q_SLOTS:
     void checkFolders();
 };
 
